# Wordnet Skill

Use Wordnet to answer dictionary like questions

## About

Uses [Wordnet](https://wordnet.princeton.edu/) to provide information. 

## Examples

* "what is the definition of ..."
* "what is the antonym of ..."

## Category
**Information**

## Tags
#Wordnet
#query
